@@ -37,8 +37,9 @@ class ValidationError(HTTPException, exceptions.ValidationError):
     def message(self):
         return 'Validation error: %s' % self.response.content
 
+    @property
     def errors(self):
-        return json.loads(self.response.content)
+        return json.loads(self.response['error'])
 
 
 class Forbidden(HTTPException, exceptions.Forbidden):
