@@ -54,10 +54,11 @@ class HTTPQuerySet(object):
         if response.status_code not in (200, 201, 204):
             raise self._exception(response)
 
-        try:
-            return json.loads(response.content)
-        except ValueError:
-            raise InvalidResource(response)
+        if response.content:
+            try:
+                return json.loads(response.content)
+            except ValueError:
+                raise InvalidResource(response)
 
     def load(self, resource, url=None):
         url = url or resource.url
@@ -98,6 +99,7 @@ class HTTPQuerySet(object):
         self.do_request(
             'delete',
             resource.url,
+            resource
         )
 
 
